#include "stockicons.h"
#include <pixmaps/pixmaps.h>

/* add Icons with given size */
static void
add_sized (GtkIconFactory *factory, const guchar *inline_data, GtkIconSize size, const gchar *stock_id)
{
  GtkIconSet *set;
  GtkIconSource *source;
  GdkPixbuf *pixbuf;
 
  pixbuf = gdk_pixbuf_new_from_inline (-1, inline_data, FALSE, NULL);
  source = gtk_icon_source_new ();
  gtk_icon_source_set_pixbuf (source, pixbuf);
  gtk_icon_source_set_size (source, size);
 
  set = gtk_icon_set_new ();                
  gtk_icon_set_add_source (set, source);
 
  gtk_icon_factory_add (factory, stock_id, set);
 
  g_object_unref (G_OBJECT (pixbuf));
  gtk_icon_source_free (source);
  gtk_icon_set_unref (set);
}

/* add our default icons */
static void
add_default_icons (GtkIconFactory *factory)
{
  add_sized (factory, stock_media_forward,  GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_FORWARD);
  add_sized (factory, stock_media_pause,    GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_PAUSE);
  add_sized (factory, stock_media_previous, GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_PREVIOUS);
  add_sized (factory, stock_media_rewind,   GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_REWIND);
  add_sized (factory, stock_media_next,     GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_NEXT);
  add_sized (factory, stock_media_play,     GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_PLAY);
  add_sized (factory, stock_media_record,   GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_RECORD);
  add_sized (factory, stock_media_stop,     GTK_ICON_SIZE_BUTTON, GST_STOCK_MEDIA_STOP);
  add_sized (factory, stock_book,           GTK_ICON_SIZE_BUTTON, GST_STOCK_BOOK);
  add_sized (factory, stock_book_open,      GTK_ICON_SIZE_BUTTON, GST_STOCK_BOOK_OPEN);
  add_sized (factory, stock_volume,         GTK_ICON_SIZE_BUTTON, GST_STOCK_VOLUME);
  add_sized (factory, stock_volume_mute,    GTK_ICON_SIZE_BUTTON, GST_STOCK_VOLUME_MUTE);
  add_sized (factory, stock_maximize,       GTK_ICON_SIZE_BUTTON, GST_STOCK_MAXIMIZE);
  add_sized (factory, stock_demaximize,     GTK_ICON_SIZE_BUTTON, GST_STOCK_DEMAXIMIZE);
}

/* init our stock items */
void
_gstplay_stock_icons_init (void)
{
  static gboolean initialized = FALSE;
  GtkIconFactory *factory;

  if (initialized)
    return;
  else
    initialized = TRUE;

  factory = gtk_icon_factory_new ();
  add_default_icons (factory);
  gtk_icon_factory_add_default (factory);
}

